Name:           wiredtiger
Version:        2.9.3
Release:        2%{?dist}
Summary:        A data storage engine
# http://source.wiredtiger.com/develop/license.html
License:        (GPLv2 or GPLv3) and MIT and BSD and ASL 2.0
URL:            http://www.wiredtiger.com/
Source0:        https://github.com/wiredtiger/wiredtiger/releases/download/%{version}/%{name}-%{version}.tar.bz2

BuildRequires:  libtool
BuildRequires:  doxygen
BuildRequires:  swig
BuildRequires:  java-devel
BuildRequires:  python2-devel
BuildRequires:  snappy-devel
BuildRequires:  zlib-devel
BuildRequires:  lz4-devel
BuildRequires:  libzstd-devel
BuildRequires:  gperftools-devel
BuildRequires:  chrpath
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

# WiredTiger does not support 32bit architectures (see bug #1208441)
ExclusiveArch:  x86_64 aarch64 ppc64le

%description
WiredTiger is a data storage engine that provides APIs for efficiently
storing data in highly concurrent applications. It includes functionality
for automatically maintaining indexes. It implements both row and column
store formats - so that all types of data can be stored space efficiently.

WiredTiger is a library that can be accessed via C, Python and Java APIs.

%package libs
Summary:        The shared libraries provided by WiredTiger

%description libs
The wiredtiger-libs package provides the WiredTiger shared libraries.

%package devel
Summary:        WiredTiger development files
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
The wiredtiger-devel package provides the WiredTiger development files.

%package -n python2-wiredtiger
%{?python_provide:%python_provide python2-wiredtiger}
# Remove before F30
Provides: %{name}-python = %{version}-%{release}
Provides: %{name}-python%{?_isa} = %{version}-%{release}
Obsoletes: %{name}-python < %{version}-%{release}
Summary:        Python bindings for WiredTiger
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description -n python2-wiredtiger
The wiredtiger-python package provides WiredTiger python API.

%package java
Summary:        Java bindings for WiredTiger
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
Requires:       javapackages-tools

%description java
The wiredtiger-java package provides WiredTiger java API.


%prep
%autosetup

./autogen.sh
# Disable -release for libtool -> disable building libwiredtiger-VERSION.so
sed -i -r "s|^(libwiredtiger_la_LDFLAGS =) .*|\1|" Makefile.am

# Remove shebang from python modules
find lang/python/wiredtiger -name '*.py' -exec sed -i '1{\@^#!/usr/bin/env python@d}' {} \;


%build
%configure --disable-static \
           --with-builtins=zlib,snappy,lz4,zstd \
           --enable-python \
           --with-python-prefix=%{buildroot}%{python_sitearch} \
           --enable-java JAR="%{java_home}/bin/jar"
#           --enable-tcmalloc

make %{?_smp_mflags} CFLAGS="%{optflags}"


%install
%make_install

# Move python files into python_sitearch directory
mv %{buildroot}%{python_sitearch}/_%{name}.so %{buildroot}%{python_sitearch}/%{name}
mv %{buildroot}%{python_sitearch}/_workgen.so %{buildroot}%{python_sitearch}/workgen

# Remove wiredtiger python test files
#rm  %{buildroot}%{python_sitearch}/%{name}/*-test.py*

# Put java libs and .jar into right location
mkdir %{buildroot}%{_libdir}/%{name}
mv %{buildroot}%{_javadir}/%{name}-%{version}/lib* %{buildroot}%{_libdir}/%{name}
rm %{buildroot}%{_libdir}/%{name}/lib*.so
mkdir -p %{buildroot}%{_jnidir}
mv %{buildroot}%{_javadir}/%{name}-%{version}/%{name}.jar %{buildroot}%{_jnidir}/
rmdir %{buildroot}%{_javadir}/%{name}-%{version}

# Remove rpath from libwiredtiger_java.so
find . -name libwiredtiger_java.so -exec chrpath --delete {} \;

# Remove .la files
rm -f %{buildroot}%{_libdir}/lib%{name}.la
rm -f %{buildroot}%{_libdir}/%{name}/lib%{name}_java.la

%check
make check

%post libs -p /sbin/ldconfig
%postun libs -p /sbin/ldconfig

%post java -p /sbin/ldconfig
%postun java -p /sbin/ldconfig


%files
%{_bindir}/wt
%{_mandir}/man1/wt.1.gz

%files libs
%doc README NEWS
%license LICENSE
%{_libdir}/lib%{name}.so.*
%{_mandir}/man3/%{name}.3.gz

%files devel
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/*

%files -n python2-wiredtiger
%dir %{python_sitearch}/%{name}
%{python_sitearch}/%{name}/*.py*
%{python_sitearch}/workgen/*.py*
%attr(0755, -, -) %{python_sitearch}/%{name}/_%{name}.so
%attr(0755, -, -) %{python_sitearch}/workgen/_workgen.so

%files java
%{_libdir}/%{name}
%{_jnidir}/%{name}.jar

%changelog
* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.9.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Aug 22 2017 Marek Skalický <mskalick@redhat.com> - 2.9.3-1
- Update to latest minor release
- Disable using tcmalloc - depends on RHBZ#1483558

* Sun Aug 20 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2.9.0-6
- Add Provides for the old name without %%_isa

* Sat Aug 19 2017 Zbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl> - 2.9.0-5
- Python 2 binary package renamed to python2-wiredtiger
  See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.9.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.9.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 12 2016 Marek Skalický <mskalick@redhat.com> - 2.9.0-1
- Update to 2.9.0
- Enable build-time testing
- Enable lz4 and zstd compressor extension
- Enable aarch64 and ppc64le

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.8.0-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Mon Apr 11 2016 Marek Skalicky <mskalick@redhat.com> - 2.8.0-1
- Upgrade to version 2.8.0

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Dec 10 2015 Marek Skalicky <mskalick@redhat.com> - 2.7.0-1
- Upgrade to version 2.7.0

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Jun 9 2015 Marek Skalicky <mskalick@redhat.com> - 2.6.1-1
- Upgrade to version 2.6.1 (#1228259)

* Fri Apr 24 2015 Marek Skalicky <mskalick@redhat.com> - 2.5.3-1
- Update to version 2.5.3

* Wed Apr 08 2015 Fedora Release Monitoring <release-monitoring@fedoraproject.org> - 2.5.2-1
- Update to 2.5.2 (#1210072)

* Thu Apr 2 2015 Marek Skalicky <mskalick@redhat.com> - 2.5.1-6
- Added ExclusiveArch: x86_64

* Fri Mar 27 2015 Marek Skalicky <mskalick@redhat.com> - 2.5.1-5
- Fixed java and python requires

* Wed Mar 25 2015 Marek Skalicky <mskalick@redhat.com> - 2.5.1-4
- Fixed python _wiretiger.so permissions
- Use python_sitearch location and with-python-prefix

* Mon Mar 23 2015 Marek Skalicky <mskalick@redhat.com> - 2.5.1-3
- Removed python test files
- Fixed java JNI location
- Add +x permission for .so file

* Mon Mar 23 2015 Marek Skalicky <mskalick@redhat.com> - 2.5.1-2
- Fixed package-review issues

* Thu Mar 12 2015 Marek Skalicky <mskalick@redhat.com> - 2.5.1-1
- Initial packaging
